==> v8.3.zip: ru_twords_ru_tw/bible/other/firstborn.md <==
# первенец, первородный

## Определение:

Первенец — это первый ребёнок в семье или первый детёныш животного.

* В Библии первенцем считался старший сын в семье.
* В древние времена первенец получал в наследство двойную часть из имущества отца.
* В жертву Богу часто приносились первородные животные мужского пола.
* Слово “первенец” может употребляться в переносном значении. Например, израильский народ был назван “первенцем”, поскольку Бог дал ему особые преимущества по сравнению с другими народами.
* Иисус назван “Божьим Первенцем” благодаря Своей власти и положению.

## Варианты перевода:

* Когда существительное “первенец” встречается в тексте без определения или объяснения, его можно перевести как “старший сын”, потому что подразумеваеся именно это. (см. [подразумевающаяся информация](rc://*/ta/man/translate/figs-explicit)).
* Это слово можно перевести как “сын, рождённый первым”, “первородный сын”.
* Когда речь идёт об Иисусе, то слово “Первенец” можно перевести как “Сын, имеющий власть над всем”, “Сын, Которому отдана вся честь и слава”.
* Внимание! Вашим читателям должно быть ясно, что Иисус не был сотворён!

(См. также: [наследовать](../kt/inherit.md), [жертва](../other/sacrifice.md), [сын](../kt/son.md))

## Ссылки на библейский текст:

* [Кол. 1:15-17](rc://*/tn/help/col/01/15)
* [Быт. 4:3-5](rc://*/tn/help/gen/04/03)
* [Быт. 29:26-27](rc://*/tn/help/gen/29/26)
* [Быт. 43:32-34](rc://*/tn/help/gen/43/32)
* [Лк. 2:6-7](rc://*/tn/help/luk/02/06)
* [Откр. 1:4-6](rc://*/tn/help/rev/01/04)

## Данные о слове:

* Номера Стронга: H1060, H1062, H1067, H1069, G4416, G5207

==> v9.2.zip: ru_twords_ru_tw/bible/other/firstborn.md <==
# первенец, первородный

## Определение:

Первенец — это первый ребёнок в семье или первый детёныш животного. 

* В Библии первенцем считался старший сын в семье. 
* В древние времена первенец получал в наследство двойную часть из имущества отца. 
* В жертву Богу часто приносились первородные животные мужского пола. 
* Слово “первенец” может употребляться в переносном значении. Например, израильский народ был назван “первенцем”, поскольку Бог дал ему особые преимущества по сравнению с другими народами. 
* Иисус назван “Божьим Первенцем” благодаря Своей власти и положению. 

## Варианты перевода:

* Когда существительное “первенец” встречается в тексте без определения или объяснения, его можно перевести как “старший сын”, потому что подразумеваеся именно это. (см. [подразумевающаяся информация](rc://ru/ta/man/translate/figs-explicit)).
* Это слово можно перевести как “сын, рождённый первым”, “первородный сын”. 
* Когда речь идёт об Иисусе, то слово “Первенец” можно перевести как “Сын, имеющий власть над всем”, “Сын, Которому отдана вся честь и слава”. 
* Внимание! Вашим читателям должно быть ясно, что Иисус не был сотворён! 

(См. также: [наследовать](../kt/inherit.md), [жертва](../other/sacrifice.md), [сын](../kt/son.md))

## Ссылки на библейский текст:

* [Кол. 1:15-17](rc://ru/tn/help/col/01/15)
* [Быт. 4:3-5](rc://ru/tn/help/gen/04/03)
* [Быт. 29:26-27](rc://ru/tn/help/gen/29/26)
* [Быт. 43:32-34](rc://ru/tn/help/gen/43/32)
* [Лк. 2:6-7](rc://ru/tn/help/luk/02/06)
* [Откр. 1:4-6](rc://ru/tn/help/rev/01/04)

## Данные о слове:

* Номера Стронга: H1060, H1062, H1067, H1069, G4416, G5207
